@@ -56,6 +56,9 @@ class AirTouch:
         message = packetmap.MessageFactory.CreateEmptyMessageOfType("GroupStatus");
         self.SendMessageToAirtouch(message)
 
+        #if the first call gets an error, not worth doing the subsequent ones
+        if hasattr(self, "error"):
+            return;
         #get the group nicknames
         nameMessage = packetmap.MessageFactory.CreateEmptyMessageOfType("GroupName");
         self.SendMessageToAirtouch(nameMessage)
